element_memory_limit_opt

Function element_memory_limit_opt 

pub fn element_memory_limit_opt(
    parameter: &str,
) -> Result<Option<usize>, String>
Find element_memory_limit=<value> in a protoc plugin parameter string.

Returns None when the option is absent, leaving ELEMENT_MEMORY_LIMIT_ENV and then TOOLING_ELEMENT_MEMORY_LIMIT to supply the value.

Errors

Returns a message if the option is present with an unparseable value.