pub fn proto_path_to_rust_module(proto_path: &str) -> StringExpand description
Convert a .proto file path to a Rust module file name.
e.g., “google/protobuf/timestamp.proto” → “google.protobuf.timestamp.rs” Convert a proto file path to a generated Rust file name.
e.g., "google/protobuf/timestamp.proto" → "google.protobuf.timestamp.rs"