#[non_exhaustive]pub struct AliasConflict {
pub camel_target: String,
pub proto_values: Vec<String>,
}Expand description
One CamelCase collision: a target identifier and the proto value names that would all convert onto it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.camel_target: StringThe UpperCamelCase identifier the colliding values map to.
proto_values: Vec<String>The proto value names that convert onto camel_target (includes a
literal variant name when an alias would shadow it).